@@ -1,6 +1,6 @@
 package Tapper::Cmd::Testrun;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Cmd::Testrun::VERSION = '5.0.7';
+$Tapper::Cmd::Testrun::VERSION = '5.0.8';
 use Moose;
 use Tapper::Model 'model';
 use DateTime;
@@ -228,6 +228,34 @@ sub rerun {
 }
 
 
+sub pause {
+        my ($self, $id) = @_;
+        my $testrun = $self->schema->resultset('TestrunScheduling')->search
+            ({
+                testrun_id => $id,
+                status => 'schedule',
+             })->first;
+        if ($testrun and $testrun->testrun_id) {
+            return $testrun->update_content({status => 'prepare'});
+        }
+        return;
+}
+
+
+sub continue {
+        my ($self, $id) = @_;
+        my $testrun = $self->schema->resultset('TestrunScheduling')->search
+            ({
+                testrun_id => $id,
+                status => 'prepare',
+             })->first;
+        if ($testrun and $testrun->testrun_id) {
+            return $testrun->update_content({status => 'schedule'});
+        }
+        return;
+}
+
+
 sub cancel
 {
         my ($self, $testrun_id, $comment) = @_;
@@ -405,6 +433,29 @@ the existing testrun given as first argument.
 
 @throws exception without class
 
+=head2 pause
+
+Pause an existing testrun by setting its state to 'prepare'.
+
+@param int      - id of original testrun
+
+@return success - testrun id
+@return error   - exception
+
+@throws exception without class
+
+=head2 continue
+
+Continue a paused testrun (status 'prepare') by setting its state back
+to 'schedule'.
+
+@param int      - id of original testrun
+
+@return success - testrun id
+@return error   - exception
+
+@throws exception without class
+
 =head2 cancel
 
 Stop a running testrun by sending the appropriate message to MCP. As
@@ -458,7 +509,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2017 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
